=========
discosuck
=========


.. image:: https://img.shields.io/pypi/v/discosuck.svg
        :target: https://pypi.python.org/pypi/discosuck

.. .. image:: https://img.shields.io/travis/devbisme/discosuck.svg
..         :target: https://travis-ci.com/devbisme/discosuck

.. .. image:: https://readthedocs.org/projects/discosuck/badge/?version=latest
..         :target: https://discosuck.readthedocs.io/en/latest/?version=latest
..         :alt: Documentation Status



Suck posts from a Discourse forum.


* Free software: MIT license

.. * Documentation: https://discosuck.readthedocs.io.


Features
--------

* Give it the URL of a Discourse forum and let it extract posts into a JSON file.
* Lets you specify the starting page of topic lists and the number of list pages to process.
* Lets you specify a delay between page accesses to reduce load on the forum server.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
